/**
 * Base communication layer for the SharePoint Framework
 *
 * @remarks
 * This package defines the base communication layer for
 * the SharePoint Framework.  For REST calls, it handles authentication,
 * logging, diagnostics, and batching.  It also simplifies requests by
 * adding default headers that follow the recommended best practices.
 *
 * @packagedocumentation
 */

import { AadHttpClient } from '@microsoft/sp-http-base';
import { AadHttpClientConfiguration } from '@microsoft/sp-http-base';
import { AadHttpClientFactory } from '@microsoft/sp-http-base';
import { AadHttpClientResponse } from '@microsoft/sp-http-base';
import { AadTokenProvider } from '@microsoft/sp-http-base';
import { AadTokenProviderFactory } from '@microsoft/sp-http-base';
import { BeforeRedirectEventArgs } from '@microsoft/sp-http-base';
import { DEPRECATED_DO_NOT_USE_OAuthTokenProvider } from '@microsoft/sp-http-base';
import { DigestCache } from '@microsoft/sp-http-base';
import { GraphRequest } from '@microsoft/sp-http-msgraph';
import { Guid } from '@microsoft/sp-core-library';
import { HttpClient } from '@microsoft/sp-http-base';
import { HttpClientConfiguration } from '@microsoft/sp-http-base';
import { HttpClientResponse } from '@microsoft/sp-http-base';
import { IAadHttpClientConfiguration } from '@microsoft/sp-http-base';
import { IAadHttpClientConfigurations } from '@microsoft/sp-http-base';
import { IAadHttpClientOptions } from '@microsoft/sp-http-base';
import { IAadTokenProvider } from '@microsoft/sp-http-base';
import { IAadTokenProviderConfiguration } from '@microsoft/sp-http-base';
import { IBeforeRedirectEventArgs } from '@microsoft/sp-http-base';
import { _IClientCachableResponse } from '@microsoft/sp-http-base';
import { IDigestCache } from '@microsoft/sp-http-base';
import { IFetchProvider } from '@microsoft/sp-http-base';
import { IGetTokenOptions } from '@microsoft/sp-http-base';
import { IHttpClientConfiguration } from '@microsoft/sp-http-base';
import { IHttpClientConfigurations } from '@microsoft/sp-http-base';
import { IHttpClientOptions } from '@microsoft/sp-http-base';
import { _IHttpRequestCacheOptions } from '@microsoft/sp-http-base';
import { IInternalAadTokenProvider } from '@microsoft/sp-http-base';
import { IPopupEventArgs } from '@microsoft/sp-http-base';
import { _IRequestCacheOptions } from '@microsoft/sp-http-base';
import { ISPHttpClientBatchConfiguration } from '@microsoft/sp-http-base';
import { ISPHttpClientBatchConfigurations } from '@microsoft/sp-http-base';
import { ISPHttpClientBatchCreationOptions } from '@microsoft/sp-http-base';
import { ISPHttpClientBatchOptions } from '@microsoft/sp-http-base';
import { ISPHttpClientCommonConfiguration } from '@microsoft/sp-http-base';
import { ISPHttpClientConfiguration } from '@microsoft/sp-http-base';
import { ISPHttpClientConfigurations } from '@microsoft/sp-http-base';
import { ISPHttpClientOptions } from '@microsoft/sp-http-base';
import { ITokenAcquisitionEventArgs } from '@microsoft/sp-http-base';
import { MSGraphClient } from '@microsoft/sp-http-msgraph';
import { MSGraphClientFactory } from '@microsoft/sp-http-msgraph';
import { MSGraphClientV3 } from '@microsoft/sp-http-msgraph';
import { ODataVersion } from '@microsoft/sp-http-base';
import { PopupEventArgs } from '@microsoft/sp-http-base';
import { ServiceKey } from '@microsoft/sp-core-library';
import { ServiceScope } from '@microsoft/sp-core-library';
import { SPHttpClient } from '@microsoft/sp-http-base';
import { SPHttpClientBatch } from '@microsoft/sp-http-base';
import { SPHttpClientBatchConfiguration } from '@microsoft/sp-http-base';
import { SPHttpClientCommonConfiguration } from '@microsoft/sp-http-base';
import { SPHttpClientConfiguration } from '@microsoft/sp-http-base';
import { SPHttpClientResponse } from '@microsoft/sp-http-base';
import { SPHttpHeader } from '@microsoft/sp-http-base';
import { TokenAcquisitionEventArgs } from '@microsoft/sp-http-base';

export { AadHttpClient }

export { AadHttpClientConfiguration }

export { AadHttpClientFactory }

export { AadHttpClientResponse }

export { AadTokenProvider }

export { AadTokenProviderFactory }

export { BeforeRedirectEventArgs }

/* Excluded from this release type: _DEPRECATED_DO_NOT_USE_GraphHttpClient */

/* Excluded from this release type: _DEPRECATED_DO_NOT_USE_GraphHttpClientConfiguration */

/* Excluded from this release type: _DEPRECATED_DO_NOT_USE_GraphHttpClientResponse */

/* Excluded from this release type: _DEPRECATED_DO_NOT_USE_IGraphHttpClientConfiguration */

/* Excluded from this release type: _DEPRECATED_DO_NOT_USE_IGraphHttpClientConfigurations */

/* Excluded from this release type: DEPRECATED_DO_NOT_USE_OAuthTokenProvider */
export { DigestCache }

export { GraphRequest }

export { HttpClient }

export { HttpClientConfiguration }

export { HttpClientResponse }

export { IAadHttpClientConfiguration }

export { IAadHttpClientConfigurations }

export { IAadHttpClientOptions }

export { IAadTokenProvider }

export { IAadTokenProviderConfiguration }

export { IBeforeRedirectEventArgs }

/* Excluded from this release type: _IClientCachableResponse */
export { IDigestCache }

/* Excluded from this release type: IFetchProvider */
export { IGetTokenOptions }

/* Excluded from this release type: _IGraphHttpClientOptions */
export { IHttpClientConfiguration }

export { IHttpClientConfigurations }

export { IHttpClientOptions }

/* Excluded from this release type: _IHttpRequestCacheOptions */

/* Excluded from this release type: IInternalAadTokenProvider */
export { IPopupEventArgs }

/* Excluded from this release type: _IRequestCacheOptions */
export { ISPHttpClientBatchConfiguration }

export { ISPHttpClientBatchConfigurations }

export { ISPHttpClientBatchCreationOptions }

export { ISPHttpClientBatchOptions }

export { ISPHttpClientCommonConfiguration }

export { ISPHttpClientConfiguration }

export { ISPHttpClientConfigurations }

export { ISPHttpClientOptions }

export { ITokenAcquisitionEventArgs }

export { MSGraphClient }

export { MSGraphClientFactory }

export { MSGraphClientV3 }

export { ODataVersion }

export { PopupEventArgs }

export { SPHttpClient }

export { SPHttpClientBatch }

export { SPHttpClientBatchConfiguration }

export { SPHttpClientCommonConfiguration }

export { SPHttpClientConfiguration }

export { SPHttpClientResponse }

export { SPHttpHeader }

export { TokenAcquisitionEventArgs }

export { }
